@@ -1,6 +1,6 @@
 from pydantic import BaseModel, HttpUrl, validator, root_validator
 
-from typing import Optional, List
+from typing import Optional, List, Dict
 
 from captur_ml_sdk.dtypes.exceptions import InvalidFilePathError
 from captur_ml_sdk.dtypes.generics import Image, TrainingMeta
@@ -56,4 +56,5 @@ class Data(BaseModel):
 class ModelTrainRequest(BaseModel):
     meta: Optional[TrainingMeta]
     models: List[Model]
+    mapping: Optional[Dict[str, Dict[str, str]]]
     data: Data
